==> fonts-osifont_0.1.20211207.orig.tar.gz: osifont-0.1.20211207/README.md <==
# What is osifont

In some European countries, CAD projects must have font which conform to IS0 3O98 specification. Commercial CADs has this font, but free CADs not. There is no available free font yet, so this project will fix this. This font will be created completely from the scratch. Font is created with free tools like FontForge, Inkscape, Gimp. Font is available under 3 licences: GNU GPL licence version 3 with GPL font exception, GNU GPL licence version 2 with GPL font exception, GNU LGPL licence version 3 with GPL font exception.

### Try it online:

- You can now [try osifont online](https://hikikomori82.github.io/)

### License

Osifont is available in 3 different licenses:

- osifont.ttf - GNU GPL licence version 3 with font exception
- osifont-gpl2fe.ttf - GNU GPL licence version 2 with font exception
- osifont-lgpl3fe.ttf - GNU LGPL licence version 3 with font exception

Disclaimer: Only contributors with at least 10% of glyphs contributed can discuss license changes.

### Recent news

  - **2021-12-07** - fixed kerning in P.(A-Za-z), removed Belarusian support in protest of latest actions on Polish border
  - **2018-09-07** - fixed kerning in E-F-C-D-L-T-Y-Z-c-r-, fixed typo in Belarusian
  - **2016-05-16** - added GPL version 2 with font exception version and LGPL version 3 with font exception version
  - **2016-03-14** - Added Māori to supported languages
  - **2015-05-06** - Added ЂЋћђ (Montenegrin, Serbian), increased right bearing of к
  - **2015-05-04** - Added ЎўІі (Belarusian), Ӂӂ (Moldovian), әҒғҚқҢңӨөҰұҺһ (Kazakh), ЀѐЍѝЌќЃѓЏџЅѕЉљЊњ (Macedonian), ЇїҐґЄє (Ukrainian)
  - **2015-05-01** - cleaned up russian glyphs, added hints, added Ḡḡ (Georgian) ʺʹ (Kazakh) and Ŭŭ (Belarus)
  - **2015-04-30** - Added more than 200 new characters (full russian support, partial japanese/chinese) from our contributors from Bosch.
  - **2014-11-14** - Dot moved to baseline (35'535 downloads)
  - **2014-05-23** - Paragraph (¶)
  - **2014-04-22** - Achievement unlocked, osifont was downloaded 30'000 times :)
  - **2014-03-29** - Irish support (ÁÉÍÓÚ áéíóú ĊċĠġḂḃḊḋ ḞḟṀṁṄṅ ṖṗṠṡṪṫ ı⁊'·´•)
  - **2014-03-24** - Armenian romanization (ǰṖṗṘṙṚṛṪṫ‛'’ʽḣḢK̇k̇)
  - **2014-03-15** - Full Azerbaijani support ÇçƏəĞğIıİiÖöŞşÜüƏəƢƣЬьƵƶӘI̡ı̡ƟɵЗзЈАјаN̡n̡.
  - **2014-03-10** - Full Vietnamese support (ẠạẢảẤấẦầẨẩẪẫẬậẮắẰằẲẳẴẵẶặ ẸẹẺẻẼẽẾếỀềỂểỄễỆệ ỈỉĨĩỊị ỌọỎỏỐốỒồỔổỖỗỘộ ỚớỜờỞởỠỡỢợ ŨũƠơƯưỤụỦủ ỨứỪừỬửỮữỰự ỲỳỴỵỶỷỸỹ)
  - **2014-03-02** - Glyphs (≈≡½¼¾№≐≙)
  - **2014-02-25** - Upper index numbers and signs (¹²³⁰⁴⁵⁶⁷⁸⁹⁺⁻⁼)

### Supported languages (40)

Afrikaans, Albanian, Azerbaijani, Bulgarian, Catalan, Croation, Czech, Danish, Dutch, English, Estonian, Finnish, French, German, Hungarian, Icelandic, Irish (including Old Irish), Italian, Kazakh, Latvian, Lithuanian, Luxembourgish, Macedonian, Maltese, Māori, Moldovian, Montenegrin (latin, cyrillic), Norwegian, Polish, Portuguese, Romanian, Russian, Serbian, Slovak, Slovene, Spanish, Swedish, Turkish, Ukrainian, Vietnamese.

### Languages supported only by romanization (4)

Armenian, Chinese (Hanyu Pinyin), Japanese (Hepburn), Georgian

### Partially supported languages (1)

Greek (few diacritics are missing but small and capital letters are ok)

### Participate

If you want to join the project, send me email to hikikomori82 at gmail dot com. I am currently very busy with other projects to create new characters myself but if you create new characters I will add them.

==> fonts-osifont_0.1.20220224.orig.tar.gz: osifont-0.1.20220224/README.md <==
# What is osifont

In some European countries, CAD projects must have font which conform to IS0 3O98 specification. Commercial CADs has this font, but free CADs not. There is no available free font yet, so this project will fix this. This font will be created completely from the scratch. Font is created with free tools like FontForge, Inkscape, Gimp. Font is available under 3 licences: GNU GPL licence version 3 with GPL font exception, GNU GPL licence version 2 with GPL font exception, GNU LGPL licence version 3 with GPL font exception.

### Try it online:

- You can now [try osifont online](https://hikikomori82.github.io/)

### License

Osifont is available in 3 different licenses:

- osifont.ttf - GNU GPL licence version 3 with font exception
- osifont-gpl2fe.ttf - GNU GPL licence version 2 with font exception
- osifont-lgpl3fe.ttf - GNU LGPL licence version 3 with font exception

Disclaimer: Only contributors with at least 10% of glyphs contributed can discuss license changes.

### Recent news

  - **2022-02-24** - removed (ЭёЁ), removed Russian support in protest of invasion of Ukraine
  - **2021-12-07** - fixed kerning in P.(A-Za-z), removed Belarusian support in protest of latest actions on Polish border
  - **2018-09-07** - fixed kerning in E-F-C-D-L-T-Y-Z-c-r-, fixed typo in Belarusian
  - **2016-05-16** - added GPL version 2 with font exception version and LGPL version 3 with font exception version
  - **2016-03-14** - Added Māori to supported languages
  - **2015-05-06** - Added ЂЋћђ (Montenegrin, Serbian), increased right bearing of к
  - **2015-05-04** - Added ЎўІі (Belarusian), Ӂӂ (Moldovian), әҒғҚқҢңӨөҰұҺһ (Kazakh), ЀѐЍѝЌќЃѓЏџЅѕЉљЊњ (Macedonian), ЇїҐґЄє (Ukrainian)
  - **2015-05-01** - cleaned up russian glyphs, added hints, added Ḡḡ (Georgian) ʺʹ (Kazakh) and Ŭŭ (Belarus)
  - **2015-04-30** - Added more than 200 new characters (full russian support, partial japanese/chinese) from our contributors from Bosch.
  - **2014-11-14** - Dot moved to baseline (35'535 downloads)
  - **2014-05-23** - Paragraph (¶)
  - **2014-04-22** - Achievement unlocked, osifont was downloaded 30'000 times :)
  - **2014-03-29** - Irish support (ÁÉÍÓÚ áéíóú ĊċĠġḂḃḊḋ ḞḟṀṁṄṅ ṖṗṠṡṪṫ ı⁊'·´•)
  - **2014-03-24** - Armenian romanization (ǰṖṗṘṙṚṛṪṫ‛'’ʽḣḢK̇k̇)
  - **2014-03-15** - Full Azerbaijani support ÇçƏəĞğIıİiÖöŞşÜüƏəƢƣЬьƵƶӘI̡ı̡ƟɵЗзЈАјаN̡n̡.
  - **2014-03-10** - Full Vietnamese support (ẠạẢảẤấẦầẨẩẪẫẬậẮắẰằẲẳẴẵẶặ ẸẹẺẻẼẽẾếỀềỂểỄễỆệ ỈỉĨĩỊị ỌọỎỏỐốỒồỔổỖỗỘộ ỚớỜờỞởỠỡỢợ ŨũƠơƯưỤụỦủ ỨứỪừỬửỮữỰự ỲỳỴỵỶỷỸỹ)
  - **2014-03-02** - Glyphs (≈≡½¼¾№≐≙)
  - **2014-02-25** - Upper index numbers and signs (¹²³⁰⁴⁵⁶⁷⁸⁹⁺⁻⁼)

### Supported languages (39)

Afrikaans, Albanian, Azerbaijani, Bulgarian, Catalan, Croation, Czech, Danish, Dutch, English, Estonian, Finnish, French, German, Hungarian, Icelandic, Irish (including Old Irish), Italian, Kazakh, Latvian, Lithuanian, Luxembourgish, Macedonian, Maltese, Māori, Moldovian, Montenegrin (latin, cyrillic), Norwegian, Polish, Portuguese, Romanian, Serbian, Slovak, Slovene, Spanish, Swedish, Turkish, Ukrainian, Vietnamese.

### Languages supported only by romanization (4)

Armenian, Chinese (Hanyu Pinyin), Japanese (Hepburn), Georgian

### Partially supported languages (1)

Greek (few diacritics are missing but small and capital letters are ok)

### Languages with no support

Belarusian, Russian

### Participate

If you want to join the project, send me email to hikikomori82 at gmail dot com. I am currently very busy with other projects to create new characters myself but if you create new characters I will add them.
